@@ -17,8 +17,8 @@ SPDX-License-Identifier: MIT
 #ifndef GENX_INTRINSIC_INTERFACE_H
 #define GENX_INTRINSIC_INTERFACE_H
 
+#include "llvm/ADT/None.h"
 #include "llvm/IR/Module.h"
-
 #include "llvm/IR/Attributes.h"
 #include "llvm/IR/Function.h"
 #include "llvm/IR/Intrinsics.h"
@@ -173,7 +173,7 @@ inline bool isGenXNonTrivialIntrinsic(const Value *V) {
 
 /// GenXIntrinsic::getGenXName(ID) - Return the LLVM name for a GenX intrinsic,
 /// such as "llvm.genx.lane.id".
-std::string getGenXName(ID id, ArrayRef<Type *> Tys = None);
+std::string getGenXName(ID id, ArrayRef<Type *> Tys = {});
 
 ID lookupGenXIntrinsicID(StringRef Name);
 
@@ -181,7 +181,7 @@ AttributeList getAttributes(LLVMContext &C, ID id);
 
 /// GenXIntrinsic::getGenXType(ID) - Return the function type for an intrinsic.
 FunctionType *getGenXType(LLVMContext &Context, GenXIntrinsic::ID id,
-                          ArrayRef<Type *> Tys = None);
+                          ArrayRef<Type *> Tys = {});
 
 /// GenXIntrinsic::getGenXDeclaration(M, ID) - Create or insert a GenX LLVM
 /// Function declaration for an intrinsic, and return it.
@@ -190,7 +190,7 @@ FunctionType *getGenXType(LLVMContext &Context, GenXIntrinsic::ID id,
 /// using iAny, fAny, vAny, or iPTRAny).  For a declaration of an overloaded
 /// intrinsic, Tys must provide exactly one type for each overloaded type in
 /// the intrinsic.
-Function *getGenXDeclaration(Module *M, ID id, ArrayRef<Type *> Tys = None);
+Function *getGenXDeclaration(Module *M, ID id, ArrayRef<Type *> Tys = {});
 
 void getIntrinsicInfoTableEntries(
     GenXIntrinsic::ID id,
@@ -262,11 +262,11 @@ inline bool isAnyNonTrivialIntrinsic(const Value *V) {
 
 /// GenXIntrinsic::getAnyName(ID) - Return the LLVM name for LLVM or GenX
 /// intrinsic, such as "llvm.genx.lane.id".
-std::string getAnyName(unsigned id, ArrayRef<Type *> Tys = None);
+std::string getAnyName(unsigned id, ArrayRef<Type *> Tys = {});
 
 /// GenXIntrinsic::getAnyType(ID) - Return the function type for an intrinsic.
 inline FunctionType *getAnyType(LLVMContext &Context, unsigned id,
-                                ArrayRef<Type *> Tys = None) {
+                                ArrayRef<Type *> Tys = {}) {
   assert(isAnyNonTrivialIntrinsic(id));
   if (isGenXIntrinsic(id))
     return getGenXType(Context, (ID)id, Tys);
@@ -294,7 +294,7 @@ bool isOverloadedRet(unsigned IntrinID);
 /// intrinsic, Tys must provide exactly one type for each overloaded type in
 /// the intrinsic.
 inline Function *getAnyDeclaration(Module *M, unsigned id,
-                                   ArrayRef<Type *> Tys = None) {
+                                   ArrayRef<Type *> Tys = {}) {
   assert(isAnyNonTrivialIntrinsic(id));
   if (isGenXIntrinsic(id)) {
     return getGenXDeclaration(M, (ID)id, Tys);
@@ -709,6 +709,7 @@ inline int getLSCVectorSize(LSCCategory Cat) {
     llvm_unreachable("no such argument");
     return Invalid;
   }
+  return Invalid;
 }
 // Returns VectorSize index.
 inline int getLSCVectorSize(unsigned IID) {
@@ -733,6 +734,7 @@ inline int getLSCDataSize(LSCCategory Cat) {
     llvm_unreachable("no such argument");
     return Invalid;
   }
+  return Invalid;
 }
 // Returns DataSize index.
 inline int getLSCDataSize(unsigned IID) {
@@ -756,6 +758,7 @@ inline int getLSCImmOffset(LSCCategory Cat) {
     llvm_unreachable("no such argument");
     return Invalid;
   }
+  return Invalid;
 }
 // Returns immediate offset index.
 inline int getLSCImmOffset(unsigned IID) {
@@ -781,6 +784,7 @@ inline int getLSCDataOrder(LSCCategory Cat) {
     llvm_unreachable("no such argument");
     return Invalid;
   }
+  return Invalid;
 }
 // Returns data order index.
 inline int getLSCDataOrder(unsigned IID) {
@@ -796,14 +800,15 @@ inline int getLSCWidth(LSCCategory Cat) {
   case LSCCategory::Fence:
   case LSCCategory::LegacyAtomic:
   case LSCCategory::Atomic:
-  case LSCCategory::Prefetch2D:
-    return 0;
   case LSCCategory::Load2D:
+  case LSCCategory::Prefetch2D:
   case LSCCategory::Store2D:
+    return 0;
   case LSCCategory::NotLSC:
     llvm_unreachable("no such argument");
     return Invalid;
   }
+  return Invalid;
 }
 // Returns width index.
 inline int getLSCWidth(unsigned IID) {
